@@ -1,4 +1,5 @@
 from typing import Any, Iterable
+
 from fastapi import HTTPException, status
 
 
@@ -66,6 +67,14 @@ class NotSupportedException(BaseHttpException):
         )
 
 
+class InternalServerException(BaseHttpException):
+    def __init__(self, detail: str = "internal_server_error"):
+        super().__init__(
+            status_code=status.HTTP_500_INTERNAL_SERVER_ERROR,
+            detail=detail,
+        )
+
+
 class UnprocessableEntityException(BaseHttpException):
     def __init__(self, detail: str, loc: Iterable[Any] | None = None, type_: str = "unprocessable_entity"):
         super().__init__(
@@ -77,5 +86,3 @@ class UnprocessableEntityException(BaseHttpException):
 class LogicalValidationException(UnprocessableEntityException):
     def __init__(self, detail: str, loc: Iterable[Any] | None = None, type_: str = "logical_error"):
         super().__init__(detail=detail, loc=loc, type_=type_)
-
-
