@@ -1,9 +1,8 @@
 import json
 from math import ceil
-from typing import Any, Optional
+from typing import Any, List, Optional
 
 from fastapi import Query
-from sqlalchemy import asc, desc
 
 
 class PaginateRequest:
@@ -19,11 +18,15 @@ class PaginateRequest:
         offset: int = 0,
         sort: Optional[str] = None,
         filters: Optional[str] = Query(None, description="e.g. title:abc"),
+        include: Optional[str] = None,
     ) -> None:
         self.limit = max(0, limit)
         self.offset = max(0, offset)
         self.sort = self._parse_sort(sort)
         self.filters = self._parse_filters(filters or "")
+        self.include_ids: List[int] = ([int(x) for x in include.split(",") if x.strip().isdigit()] if include else [])[
+            :50
+        ]
 
     @staticmethod
     def _parse_sort(sort_str: Optional[str]) -> list[dict[str, str]]:
@@ -75,6 +78,8 @@ class PaginateRequest:
             filters_dict[key] = value_cast
         return filters_dict
 
+    def remove_deleted(self, deleted_at_field: str = "deleted_at"):
+        self.filters = self.filters | {"deleted_at": None}
 
 
 class PaginateResponse:
